==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/extensions-core/multi-stage-query/src/main/java/org/apache/druid/msq/indexing/error/WorkerRpcFailedFault.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.msq.indexing.error;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;

import java.util.Objects;

@JsonTypeName(WorkerRpcFailedFault.CODE)
public class WorkerRpcFailedFault extends BaseMSQFault
{
  static final String CODE = "WorkerRpcFailed";

  private final String workerTaskId;

  @JsonCreator
  public WorkerRpcFailedFault(@JsonProperty("workerTaskId") final String workerTaskId)
  {
    super(CODE, "RPC call to task failed unrecoverably: [%s]", workerTaskId);
    this.workerTaskId = workerTaskId;
  }

  @JsonProperty
  public String getWorkerTaskId()
  {
    return workerTaskId;
  }

  @Override
  public boolean equals(Object o)
  {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    if (!super.equals(o)) {
      return false;
    }
    WorkerRpcFailedFault that = (WorkerRpcFailedFault) o;
    return Objects.equals(workerTaskId, that.workerTaskId);
  }

  @Override
  public int hashCode()
  {
    return Objects.hash(super.hashCode(), workerTaskId);
  }
}

==> apache-druid-32.0.1-src.tar.gz: apache-druid-32.0.1-src/extensions-core/multi-stage-query/src/main/java/org/apache/druid/msq/indexing/error/WorkerRpcFailedFault.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.msq.indexing.error;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;

import java.util.Objects;

@JsonTypeName(WorkerRpcFailedFault.CODE)
public class WorkerRpcFailedFault extends BaseMSQFault
{
  public static final String CODE = "WorkerRpcFailed";

  private final String workerTaskId;

  @JsonCreator
  public WorkerRpcFailedFault(@JsonProperty("workerTaskId") final String workerTaskId)
  {
    super(CODE, "RPC call to task failed unrecoverably: [%s]", workerTaskId);
    this.workerTaskId = workerTaskId;
  }

  @JsonProperty
  public String getWorkerTaskId()
  {
    return workerTaskId;
  }

  @Override
  public boolean equals(Object o)
  {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    if (!super.equals(o)) {
      return false;
    }
    WorkerRpcFailedFault that = (WorkerRpcFailedFault) o;
    return Objects.equals(workerTaskId, that.workerTaskId);
  }

  @Override
  public int hashCode()
  {
    return Objects.hash(super.hashCode(), workerTaskId);
  }
}
